/* Sale.h
Copyright (c) 2014 by Michael Zahniser

Endless Sky is free software: you can redistribute it and/or modify it under the
terms of the GNU General Public License as published by the Free Software
Foundation, either version 3 of the License, or (at your option) any later version.

Endless Sky is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE.  See the GNU General Public License for more details.
*/

#ifndef SALE_H_
#define SALE_H_

#include "DataNode.h"
#include "Set.h"

#include <algorithm>
#include <set>
#include <vector>



// Class representing a set of items that are for sale on a given planet.
// Multiple sale sets can be merged together into a single one.
template <class Item>
class Sale : public std::set<const Item *> {
public:
	void Load(const DataNode &node, const Set<Item> &items);
	
	void Add(const Sale<Item> &other);
	
	bool Has(const Item *item) const;
};



template <class Item>
void Sale<Item>::Load(const DataNode &node, const Set<Item> &items)
{
	for(const DataNode &child : node)
	{
		if(child.Token(0) == "clear" && child.Size() == 1)
			this->clear();
		else if(child.Token(0) == "clear" && child.Size() >= 2)
		{
			if(this->find(items.Get(child.Token(1))) != this->end())
				this->erase(this->find(items.Get(child.Token(1))));
		}
		else
			this->insert(items.Get(child.Token(0)));
	}
}



template <class Item>
void Sale<Item>::Add(const Sale<Item> &other)
{
	this->insert(other.begin(), other.end());
}



template <class Item>
bool Sale<Item>::Has(const Item *item) const
{
	return this->count(item);
}



#endif
